"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.l2Endpoints = exports.l1Endpoints = exports.calculateTimestampForPeriod = exports.PERIOD_IN_HOURS = exports.Period = void 0;
const subHours_1 = __importDefault(require("date-fns/subHours"));
const graphql_request_1 = require("graphql-request");
// @ts-ignore
// eslint-disable-next-line import/no-unresolved
const contracts_interface_1 = require("@synthetixio/contracts-interface");
const constants_1 = require("./constants");
Object.defineProperty(exports, "l1Endpoints", { enumerable: true, get: function () { return constants_1.l1Endpoints; } });
Object.defineProperty(exports, "l2Endpoints", { enumerable: true, get: function () { return constants_1.l2Endpoints; } });
const queries = __importStar(require("../queries"));
const utils_1 = require("./utils");
var Period;
(function (Period) {
    Period["ONE_HOUR"] = "ONE_HOUR";
    Period["FOUR_HOURS"] = "FOUR_HOURS";
    Period["ONE_DAY"] = "ONE_DAY";
    Period["ONE_WEEK"] = "ONE_WEEK";
    Period["ONE_MONTH"] = "ONE_MONTH";
    Period["ONE_YEAR"] = "ONE_YEAR";
})(Period || (Period = {}));
exports.Period = Period;
const PERIOD_IN_HOURS = {
    ONE_HOUR: 1,
    FOUR_HOURS: 4,
    ONE_DAY: 24,
    ONE_WEEK: 168,
    ONE_MONTH: 730,
    ONE_YEAR: 8760,
};
exports.PERIOD_IN_HOURS = PERIOD_IN_HOURS;
const getEndpointForNetwork = (networkId, endpoints) => {
    if (endpoints[networkId]) {
        return endpoints[networkId];
    }
    throw new Error('unsupported network');
};
const calculateTimestampForPeriod = (periodInHours) => Math.trunc((0, subHours_1.default)(new Date().getTime(), periodInHours).getTime() / 1000);
exports.calculateTimestampForPeriod = calculateTimestampForPeriod;
const DEFAULT_ENDPOINTS = {
    [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.snx,
    [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.snx,
    [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.snxKovan,
    [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.snxKovan,
};
const getData = ({ params, queryMethod, networkId, endpoints, }) => __awaiter(void 0, void 0, void 0, function* () {
    const endpoint = getEndpointForNetwork(networkId, endpoints != null ? Object.assign(Object.assign({}, DEFAULT_ENDPOINTS), endpoints) : DEFAULT_ENDPOINTS);
    const formattedParams = (0, utils_1.formatParams)(params);
    return (0, utils_1.requestHelper)({
        endpoint,
        queryMethod,
        variables: formattedParams,
    });
});
const synthetixData = ({ networkId }) => ({
    synthExchanges: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createSynthExchangesQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.exchanges,
                [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanges,
            },
        });
        return response != null ? response.synthExchanges.map(queries.parseSynthExchanges) : null;
    }),
    synthetix: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const query = queries.createSynthetixQuery(params);
        const response = yield (0, graphql_request_1.request)(networkId === contracts_interface_1.NetworkId.Mainnet ? constants_1.l1Endpoints.snx : constants_1.l2Endpoints.snx, query);
        return response != null ? queries.parseSynthetix(response.synthetixes[0]) : null;
    }),
    feesClaimed: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createFeesClaimedQuery,
            networkId,
        });
        return response != null ? response.feesClaimeds.map(queries.parseFeesClaimed) : null;
    }),
    issued: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createIssuedQuery,
            networkId,
        });
        return response != null ? response.issueds.map(queries.parseIssued) : null;
    }),
    burned: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createBurnedQuery,
            networkId,
        });
        return response != null ? response.burneds.map(queries.parseBurned) : null;
    }),
    dailyIssued: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createDailyIssuedQuery,
            networkId,
        });
        return response != null ? response.dailyIssueds.map(queries.parseIssued) : null;
    }),
    dailyBurned: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createDailyBurnedQuery,
            networkId,
        });
        return response != null ? response.dailyBurneds.map(queries.parseBurned) : null;
    }),
    snxPrices: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createSnxPriceQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.exchanges,
                [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanges,
            },
        });
        return response != null
            ? response[queries.getSNXPricesQueryResponseAttr(params.timeSeries)].map(queries.parseSnxPrice)
            : null;
    }),
    rateUpdates: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createRateUpdatesQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.exchanges,
                [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanges,
            },
        });
        return response != null ? response.rateUpdates.map(queries.parseRates) : null;
    }),
    debtSnapshots: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createDebtSnapshotQuery,
            networkId,
        });
        return response != null ? response.debtSnapshots.map(queries.parseDebtSnapshot) : null;
    }),
    snxHolders: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createSnxHolderQuery,
            networkId,
        });
        return response != null ? response.snxholders.map(queries.parseSnxHolder) : null;
    }),
    shorts: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createShortsQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.shorts,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.shorts,
            },
        });
        return response != null ? response.shorts.map(queries.parseShort) : null;
    }),
    exchangeEntrySettleds: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createExchangeEntrySettledsQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.exchanger,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanger,
                [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.exchangerKovan,
                [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.exchangerKovan,
            },
        });
        return response != null
            ? response.exchangeEntrySettleds.map(queries.parseExchangeEntrySettleds)
            : null;
    }),
    exchangeTotals: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createExchangeTotalsQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.exchanges,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanges,
                [contracts_interface_1.NetworkId.Kovan]: constants_1.l1Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Kovan-Ovm']]: constants_1.l2Endpoints.exchangesKovan,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.exchanges,
            },
        });
        return response != null
            ? response[queries.getExchangeTotalsQueryResponseAttr(params.timeSeries)].map(queries.parseExchangeTotals)
            : null;
    }),
    dailyTotalActiveStakers: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createDailyTotalActiveStakersQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.snx,
                [contracts_interface_1.NetworkId['Mainnet-Ovm']]: constants_1.l2Endpoints.snx,
            },
        });
        return response != null
            ? response.totalDailyActiveStakers.map(queries.parseDailyTotalActiveStakers)
            : null;
    }),
    accountsFlaggedForLiquidation: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createAccountsFlaggedForLiquidationQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.liquidations,
            },
        });
        return response != null
            ? response.accountFlaggedForLiquidations.map(queries.parseAccountsFlaggedForLiquidation)
            : null;
    }),
    synthHolders: (params) => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield getData({
            params,
            queryMethod: queries.createSynthHoldersQuery,
            networkId,
            endpoints: {
                [contracts_interface_1.NetworkId.Mainnet]: constants_1.l1Endpoints.snx,
            },
        });
        return response != null ? response.synthHolders.map(queries.parseSynthHolders) : null;
    }),
});
exports.default = synthetixData;
