"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatEther = exports.requestHelper = exports.getSortedField = exports.getResponseName = exports.getHashFromId = exports.hexToAscii = exports.formatTimestamp = exports.createGQLWhereString = exports.createGQLBlockNumberString = exports.formatParams = void 0;
const graphql_request_1 = require("graphql-request");
const ethers_1 = require("ethers");
const lodash_1 = require("lodash");
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const constants_1 = require("./constants");
const formatParams = (obj) => {
    if (obj == null) {
        return {};
    }
    const newObj = Object.assign({}, obj);
    Object.keys(newObj).forEach((key) => newObj[key] == undefined && delete newObj[key]);
    return newObj;
};
exports.formatParams = formatParams;
const createGQLBlockNumberString = (blockNumber) => blockNumber != null ? `\nblock: { number: ${blockNumber} }\n` : '';
exports.createGQLBlockNumberString = createGQLBlockNumberString;
const createGQLWhereString = (data) => {
    const whereString = data.reduce((acc, [key, param]) => {
        if (param != null) {
            return (acc += `${key}: $${param},`);
        }
        return acc;
    }, '');
    return whereString !== '' ? '{ ' + whereString.slice(0, -1) + ' }' : '{}';
};
exports.createGQLWhereString = createGQLWhereString;
const formatTimestamp = (ts) => Number(ts) * 1000;
exports.formatTimestamp = formatTimestamp;
const hexToAscii = (str) => {
    const hex = str.toString();
    let out = '';
    for (let n = 2; n < hex.length; n += 2) {
        const nextPair = hex.substr(n, 2);
        if (nextPair !== '00') {
            out += String.fromCharCode(parseInt(nextPair, 16));
        }
    }
    return out;
};
exports.hexToAscii = hexToAscii;
const getHashFromId = (id) => id.split('-')[0];
exports.getHashFromId = getHashFromId;
const setPaginationMaxVariable = ({ variables, numTries, }) => {
    if (!variables) {
        return {};
    }
    const responseVariables = Object.assign({}, variables);
    const resultsToDate = numTries.times(constants_1.GQL_RESPONSE_LIMIT);
    if (variables.max == null || variables.max > resultsToDate) {
        responseVariables.max =
            variables.max == null
                ? constants_1.GQL_RESPONSE_LIMIT
                : variables.max - resultsToDate.toNumber() >= constants_1.GQL_RESPONSE_LIMIT
                    ? constants_1.GQL_RESPONSE_LIMIT
                    : variables.max - resultsToDate.toNumber();
    }
    return responseVariables;
};
const getResponseName = (query) => query.substring(query.indexOf('query ') + 'query '.length, query.indexOf('('));
exports.getResponseName = getResponseName;
const getSortedField = (query) => {
    if (query.indexOf('orderBy: ') !== -1) {
        const beginSortedFieldIndex = query.indexOf('orderBy: ') + 'orderBy: '.length;
        const tempString = query.substr(beginSortedFieldIndex);
        return tempString.substr(0, tempString.indexOf('\n'));
    }
    // id is the default field to sort with pagination if there is no orderBy field
    return 'id';
};
exports.getSortedField = getSortedField;
const requestHelper = ({ endpoint, variables, prevOutput, field, queryMethod, numTries = new bignumber_js_1.default(0), }) => __awaiter(void 0, void 0, void 0, function* () {
    const responseVariables = setPaginationMaxVariable({ variables, numTries });
    if (prevOutput && prevOutput.length > 0) {
        const paginationField = prevOutput[0][field];
        const numberRegex = /^\d+$/;
        const autoGeneratedPaginationField = numberRegex.test(paginationField)
            ? Number(paginationField)
            : paginationField;
        const newQuery = queryMethod(Object.assign(Object.assign({}, responseVariables), { autoGeneratedPaginationField }));
        const responseName = (0, exports.getResponseName)(newQuery);
        const newResponse = yield (0, graphql_request_1.request)(endpoint, newQuery, Object.assign(Object.assign({}, responseVariables), { autoGeneratedPaginationField }));
        const newResponseData = (0, lodash_1.get)(newResponse, `${responseName}`, []);
        if (newResponseData.length === constants_1.GQL_RESPONSE_LIMIT) {
            return (0, exports.requestHelper)({
                endpoint,
                variables,
                field,
                queryMethod,
                prevOutput: [...(0, lodash_1.sortBy)(newResponseData, ['timestamp']), ...prevOutput],
                numTries: numTries.plus(1),
            });
        }
        return { [responseName]: [...(0, lodash_1.sortBy)(newResponseData, ['timestamp']), ...prevOutput] };
    }
    else {
        const query = queryMethod(responseVariables);
        const responseName = (0, exports.getResponseName)(query);
        const field = (0, exports.getSortedField)(query);
        const response = yield (0, graphql_request_1.request)(endpoint, query, responseVariables);
        const responseData = (0, lodash_1.get)(response, `${responseName}`, []);
        if (responseData.length === constants_1.GQL_RESPONSE_LIMIT) {
            return (0, exports.requestHelper)({
                endpoint,
                variables,
                field,
                queryMethod,
                prevOutput: (0, lodash_1.sortBy)(responseData, [field]),
                numTries: numTries.plus(1),
            });
        }
        return response;
    }
});
exports.requestHelper = requestHelper;
const formatEther = (n) => {
    if (!n)
        return '0';
    try {
        return ethers_1.ethers.utils.formatEther(n).toString();
    }
    catch (_a) {
        return n.toString();
    }
};
exports.formatEther = formatEther;
