import { SynthExchange, Short as UnformatedShort, ShortLoanChange, ShortCollateralChange, ShortLiquidation } from '../generated/graphql';
export declare type BaseQueryParams = {
    max?: number;
    autoGeneratedPaginationField?: number;
    blockNumber?: number;
};
export declare type SynthExchangeQueryParams = {
    maxBlock?: number;
    fromAddress?: string;
    minTimestamp?: number;
} & BaseQueryParams;
export declare type FeesClaimedParams = {
    account?: string;
} & BaseQueryParams;
export declare type IssuedQueryParams = {
    account?: string;
    minBlock?: number;
} & BaseQueryParams;
export declare type DailyIssuedQueryParams = {
    minTimestamp?: number;
} & BaseQueryParams;
export declare type SnxPriceParams = {
    timeSeries: '1d' | '15m';
} & BaseQueryParams;
export declare type BurnedQueryParams = IssuedQueryParams;
export declare type DailyBurnedQueryParams = DailyIssuedQueryParams;
export declare type DebtSnapshotParams = {
    minBlock?: number;
    maxBlock?: number;
    account?: string;
} & BaseQueryParams;
export declare type ShortQueryParams = {
    id?: string;
    isOpen?: boolean;
    account?: string;
} & BaseQueryParams;
export declare type SnxHolderParams = {
    maxCollateral?: number;
    minCollateral?: number;
    address?: string;
    minMints?: number;
    minClaims?: number;
    addresses?: string[];
} & BaseQueryParams;
export declare type RateUpdateQueryParams = {
    synth?: string;
    minTimestamp?: number;
} & BaseQueryParams;
export declare type ExchangeEntrySettledsParams = {
    from?: string;
    minExchangeTimestamp?: number;
    maxExchangeTimestamp?: number;
} & BaseQueryParams;
export declare type SynthExchangeExpanded = SynthExchange & {
    hash: string;
};
export declare type DailyTotalActiveStakersParams = BaseQueryParams;
export declare type ExchangeTotalsParams = {
    timeSeries: string;
} & BaseQueryParams;
export declare type AccountsFlaggedForLiquidationParams = {
    account?: string;
    minTimestamp?: number;
    maxTimestamp?: number;
} & BaseQueryParams;
export declare type SynthHolderParams = {
    id?: string;
    synth?: string;
} & BaseQueryParams;
/**
 * Shorts have many relationships between entities although we are not taking advantage
 * of all of them so we are removing the types we don't use
 */
export interface Short extends Omit<UnformatedShort, 'contractData' | 'liquidations' | 'collateralChanges' | 'loanChanges'> {
    loanChanges: Omit<ShortLoanChange, 'short'>[];
    collateralChanges: Omit<ShortCollateralChange, 'short'>[];
    liquidations: Omit<ShortLiquidation, 'short'>[];
}
export declare type OptionsMarket = {
    address: string;
    timestamp: number;
    creator: string;
    currencyKey: string;
    strikePrice: string;
    biddingEndDate: number;
    maturityDate: number;
    expiryDate: number;
    isOpen: boolean;
    longPrice: string;
    shortPrice: string;
    poolSize: string;
    result: string | null;
};
export declare type DailyTotalActiveStakers = {
    id: number;
    count: number;
};
export declare type ExchangeTotals = {
    id: number;
    trades: number;
    exchangers: number;
    exchangeUSDTally: number;
    totalFeesGeneratedInUSD: number;
};
export declare type AccountFlaggedForLiquidation = {
    deadline: number;
    account: string;
    collateral: number;
    collateralRatio: number;
    liquidatableNonEscrowSNX: number;
};
export declare type SynthHolder = {
    address: string;
    synth: string;
    balanceOf: number;
};
//# sourceMappingURL=types.d.ts.map